@@ -1,13 +1,13 @@
 """Webcam"""
 from tkinter import Label
-from cv2 import cv2
 from PIL import Image, ImageTk
+import cv2
 
 
 class Box:
     """Box"""
 
-    def __init__(self, window, width, height):
+    def __init__(self, window, width=450, height=450):
         self.window = window
         self.width = width
         self.height = height
